/*
See LICENSE folder for this sample’s licensing information.

Abstract:
The initial view controller for the app to display weather forecast data in a collection view.
*/

import UIKit
import WeatherFramework

class ForecastViewController: UICollectionViewController {

    var weatherForecastData = WeatherForecast.loadSharedData()

    // MARK: - View lifecycle

    override func viewDidLoad() {
        super.viewDidLoad()

        // Register the collection view cells.
        let weatherForecastCellNib = UINib(nibName: "ForecastCollectionViewCell", bundle: nil)
        collectionView?.register(weatherForecastCellNib, forCellWithReuseIdentifier: ForecastCollectionViewCell.reuseIdentifier)
    }

    // MARK: - Collection view data source

    override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return weatherForecastData.count
    }

    override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {

        guard let cell = collectionView.dequeueReusableCell(withReuseIdentifier: ForecastCollectionViewCell.reuseIdentifier,
                                                            for: indexPath) as? ForecastCollectionViewCell
        else { preconditionFailure("Expected to dequeue a ForecastCell") }

        let weatherForecast = weatherForecastData[indexPath.item]
        cell.dateLabel.text = weatherForecast.daysFromNowDescription
        cell.forecastImageView.image = weatherForecast.forecast.imageAsset
        cell.forecastLabel.text = weatherForecast.forecast.description

        return cell
    }

    // MARK: - Action methods

    @IBAction func refreshForecast() {
        // Generate new forecast data, save it to disk and reload the collection view.
        weatherForecastData = WeatherForecast.randomForecastData()
        WeatherForecast.saveSharedData(data: weatherForecastData)
        collectionView?.reloadData()
    }
}

extension ForecastViewController: UICollectionViewDelegateFlowLayout {

    func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout,
                        sizeForItemAt indexPath: IndexPath) -> CGSize {
        // The full size of the collection view minus any top or bottom bars.
        return collectionView.bounds.inset(by: collectionView.adjustedContentInset).size
    }
}

extension ForecastViewController {

    public func scrollToForecast(index: Int) {
        let indexPath = IndexPath(item: index, section: 0)
        collectionView?.scrollToItem(at: indexPath, at: .centeredHorizontally, animated: false)
    }

}
