/*
See LICENSE folder for this sample’s licensing information.

Abstract:
An enum representing some of the the different types of weather.
*/

import UIKit

public enum Weather: Int, Codable {

    case sun = 0
    case cloud
    case wind
    case rain
    case storm

    static var allValues = [ sun, cloud, wind, rain, storm ]

    public var description: String {
        switch self {
        case .sun: return "Sunny"
        case .cloud: return "Cloudy"
        case .wind: return "Windy"
        case .rain: return "Rainy"
        case .storm: return "Stormy"
        }
    }

    var imageAssetName: String {
        switch self {
        case .sun: return "Sun"
        case .cloud: return "Cloud"
        case .wind: return "Wind"
        case .rain: return "Rain"
        case .storm: return "Storm"
        }
    }

    /// - Tag: LoadAssetFromEmbeddedFramework
    public var imageAsset: UIImage {
        let assetName = self.imageAssetName
        let assetBundle = Bundle(identifier: "com.example.apple-samplecode.WeatherFramework")
        guard let image = UIImage(named: assetName, in: assetBundle, compatibleWith: nil)
            else { preconditionFailure("Expected an image named \(assetName)") }

        return image
    }

}
